Index: src/snapshot/serialize.cc |
diff --git a/src/snapshot/serialize.cc b/src/snapshot/serialize.cc |
index 4be1da2c9a346f6f6f8d5acbb64837e227efe055..09c646781f5c82526ec46d4a39fc2536d73735fa 100644 |
--- a/src/snapshot/serialize.cc |
+++ b/src/snapshot/serialize.cc |
@@ -1006,15 +1006,15 @@ bool Deserializer::ReadData(Object** current, Object** limit, int source_space, |
ALL_SPACES(kBackref, kPlain, kStartOfObject) |
ALL_SPACES(kBackrefWithSkip, kPlain, kStartOfObject) |
#if defined(V8_TARGET_ARCH_MIPS) || defined(V8_TARGET_ARCH_MIPS64) || \ |
- defined(V8_TARGET_ARCH_PPC) |
+ defined(V8_TARGET_ARCH_PPC) || V8_EMBEDDED_CONSTANT_POOL |
// Deserialize a new object from pointer found in code and write |
// a pointer to it to the current object. Required only for MIPS, PPC or |
// ARM with ool constant pool, and omitted on the other architectures |
// because it is fully unrolled and would cause bloat. |
ALL_SPACES(kNewObject, kFromCode, kStartOfObject) |
// Find a recently deserialized code object using its offset from the |
// current allocation point and write a pointer to it to the current |
// object. Required only for MIPS, PPC or ARM with ool constant pool. |
ALL_SPACES(kBackref, kFromCode, kStartOfObject) |
ALL_SPACES(kBackrefWithSkip, kFromCode, kStartOfObject) |
#endif |
@@ -1031,7 +1031,7 @@ bool Deserializer::ReadData(Object** current, Object** limit, int source_space, |
CASE_STATEMENT(kRootArray, kPlain, kStartOfObject, 0) |
CASE_BODY(kRootArray, kPlain, kStartOfObject, 0) |
#if defined(V8_TARGET_ARCH_MIPS) || defined(V8_TARGET_ARCH_MIPS64) || \ |
- defined(V8_TARGET_ARCH_PPC) |
+ defined(V8_TARGET_ARCH_PPC) || V8_EMBEDDED_CONSTANT_POOL |
// Find an object in the roots array and write a pointer to it to in code. |
CASE_STATEMENT(kRootArray, kFromCode, kStartOfObject, 0) |
CASE_BODY(kRootArray, kFromCode, kStartOfObject, 0) |
@@ -1006,15 +1006,15 @@ bool Deserializer::ReadData(Object** current, Object** limit, int source_space, |
// Deserialize a new object from pointer found in code and write |
// a pointer to it to the current object. Required only for MIPS, PPC or |
- // ARM with ool constant pool, and omitted on the other architectures |
+ // ARM with embedded constant pool, and omitted on the other architectures |
// because it is fully unrolled and would cause bloat. |
ALL_SPACES(kNewObject, kFromCode, kStartOfObject) |
@@ -1006,15 +1006,15 @@ bool Deserializer::ReadData(Object** current, Object** limit, int source_space, |
// Find a recently deserialized code object using its offset from the |
// current allocation point and write a pointer to it to the current |
- // object. Required only for MIPS, PPC or ARM with ool constant pool. |
+ // object. Required only for MIPS, PPC or ARM with embedded constant pool. |
ALL_SPACES(kBackref, kFromCode, kStartOfObject) |
ALL_SPACES(kBackrefWithSkip, kFromCode, kStartOfObject) |